@@ -1,3 +1,3 @@
 import sys, os
 myPath = os.path.dirname(os.path.abspath(__file__))
-sys.path.insert(0, myPath + '/../bigbang/')
+sys.path.insert(0, myPath + '/../src/bigbang/')
